#app,body,html{height:100%;width:100%}.title-container[data-v-ca98837c]{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.title-button[data-v-ca98837c]{margin-left:1rem}.feed-title[data-v-ca98837c]{color:#000}.list-title[data-v-ca98837c]{margin-top:1.5rem}table[data-v-ca98837c]{width:100%}.keyword-container[data-v-353de630]{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.add-button[data-v-353de630]{margin-left:1rem;color:#000}.delete-button[data-v-353de630]{margin-left:.5rem;color:#000}table[data-v-38ae518d]{width:100%}.title-container[data-v-38ae518d]{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.title-button[data-v-38ae518d]{margin-left:1rem}.list-title[data-v-38ae518d]{margin-top:1.5rem}
/*# sourceMappingURL=app.753316ec71241f0181971aded846512b.css.map */