<!DOCTYPE html><html><head><meta charset=utf-8><meta name=viewport content="width=device-width,initial-scale=1"><title>RSS Transmission WEBUI</title><link href=https://cdn.bootcss.com/bulma/0.6.2/css/bulma.min.css rel=stylesheet><link href=https://cdn.bootcss.com/font-awesome/4.7.0/css/font-awesome.min.css rel=stylesheet><link href=/static/css/app.753316ec71241f0181971aded846512b.css rel=stylesheet></head><body><div id=app></div><script type=text/javascript src=/static/js/manifest.f4e3280bc7462d6e3140.js></script><script type=text/javascript src=/static/js/vendor.b2eb89e18d88c6a43cb2.js></script><script type=text/javascript src=/static/js/app.049ff269dfe5e0cd3bb3.js></script></body></html>